using System;
using System.Collections;
using TXTextControl;
using Keyoti.RapidSpell;

namespace TX_Text_Control_Words
{
	/// <summary>
	/// Summary description for TXHelper.
	/// </summary>
	public class TXHelper
	{
		RapidSpellAsYouType ayt;
		RapidSpellDialog dia;
		TXTextControl.TextControl txc;
		TXTextControlAdapter dialogAdapter;
		TXTextControlAdapter[] adapters;
		bool isTextFrameActive = false;

		public bool IsTextFrameActive{ get{ return isTextFrameActive; }}


		/// <summary>
		/// Configures the spell checkers to work with the text control, pass a null
		/// spell checker object if not being used.
		/// </summary>
		public TXHelper(RapidSpellAsYouType ayt, RapidSpellDialog dia, TXTextControl.TextControl txc)
		{
			this.ayt = ayt;
			this.dia = dia;
			this.txc = txc;

			if(dia!=null)
			{
				dialogAdapter = new TXTextControlAdapter(txc);
				dialogAdapter.WorkWithCurrentlyActiveElementOnly = true;
				this.dia.ThirdPartyTextComponentToCheck = dialogAdapter;
				dia.SpellCheckStarted +=new Keyoti.RapidSpell.RapidSpellDialog.SpellCheckEventHandler(dia_SpellCheckStarted);
				dia.SpellCheckFinished += new Keyoti.RapidSpell.RapidSpellDialog.SpellCheckEventHandler(dia_SpellCheckFinished);
			}

			if(ayt!=null)
			{
				this.txc.TextFrameCreated +=new TextFrameEventHandler(txc_TextFrameCreated);
				adapters = (TXTextControlAdapter[]) getBasisAdapters().ToArray(typeof (TXTextControlAdapter));
				this.ayt.UpdateAllTextBoxes = false;
				this.ayt.TextComponents = adapters;
			}

			this.txc.TextFrameActivated+= new TextFrameEventHandler(txc_TextFrameActivated);
			this.txc.TextFrameDeactivated+=new TextFrameEventHandler(txc_TextFrameDeactivated);
			
		}

		ArrayList getBasisAdapters()
		{
			ArrayList adaps = new ArrayList();
			TXTextControlAdapter adap;

			//add main adapter
			adap = new TXTextControlAdapter(this.txc);
			adaps.Add(adap);

			//add adapters for headers/footers
			foreach (HeaderFooter hf in this.txc.HeadersAndFooters)
			{
				adap = new TXTextControlAdapter(this.txc);
				adap.HeaderFooter = hf;
				adaps.Add(adap);
			}
			return adaps;
		}

		private void dia_SpellCheckStarted(object sender, Keyoti.RapidSpell.Event.SpellCheckEventArgs e)
		{
			dialogAdapter.IgnoreHeaderFooterDeactivationEvents = true;
		}

		private void dia_SpellCheckFinished(object sender, Keyoti.RapidSpell.Event.SpellCheckEventArgs e)
		{
			dialogAdapter.IgnoreHeaderFooterDeactivationEvents = false;
		}

		//used for AYT only, this is only called when text frames come from the CLIPBOARD
		private void txc_TextFrameCreated(object sender, TextFrameEventArgs e)
		{
			OnTextFrameCreated(e.TextFrame);
		}

		//used for AYT only
		/// <summary>
		/// Call when adding a TextFrame
		/// </summary>
		/// <param name="tf"></param>
		public void OnTextFrameCreated(TextFrame tf)
		{
			ArrayList basis = new ArrayList();
			TXTextControlAdapter adap;

			//refresh old adapters, note we must create new adapters as old ones are retired below
			foreach(TXTextControlAdapter a in adapters)
			{

				adap = new TXTextControlAdapter(this.txc);
				adap.SetWith(a);
				basis.Add(adap);
			}

			//text frame adapter
			adap = new TXTextControlAdapter(this.txc);
			adap.TextFrame = tf;
			basis.Add(adap);

			adapters = (TXTextControlAdapter[]) basis.ToArray(typeof (TXTextControlAdapter));

			//retire the old ones
			ayt.TextComponents = null;
			//add the new ones
			ayt.TextComponents = adapters;
		}





		private void txc_TextFrameActivated(object sender, TextFrameEventArgs e)
		{
			isTextFrameActive = true;
		}

		private void txc_TextFrameDeactivated(object sender, TextFrameEventArgs e)
		{
			isTextFrameActive = false;
		}
	}
}
